@@ -1,9 +1,7 @@
-# $Id: GUI.pm,v 1.27 2001/08/19 09:56:45 joern Exp $
+# $Id: GUI.pm,v 1.29 2001/08/19 18:03:03 joern Exp $
 
 package JaM::GUI;
 
-$VERSION = "0.06";
-
 @ISA = qw ( JaM::GUI::Component );
 
 use strict;
@@ -235,6 +233,16 @@ sub create_menubar {
 			$db->build_configuration_window;
 		  } },
 
+                { path        => '/Edit/_User Configuration',
+		  accelerator => '<control>U',
+                  callback    => sub {
+		  	require JaM::GUI::Config;
+		  	my $conf = JaM::GUI::Config->new (
+				dbh => $self->dbh
+			);
+			$conf->build;
+		  } },
+
                 { path        => '/_Message',
                   type        => '<Branch>' },
                 { path        => '/Message/_New Message',
